diff --git a/core/includes/update.inc b/core/includes/update.inc
index 5b045f66fb2988dca956949feac5d1999452ef8c..2bbc9ffb88703d3e6f132ff89d4f74237be50152 100644
--- a/core/includes/update.inc
+++ b/core/includes/update.inc
@@ -499,7 +499,11 @@ function update_fix_d8_requirements() {
   global $conf;
 
   if (drupal_get_installed_schema_version('system') < 8000 && !update_variable_get('update_d8_requirements', FALSE)) {
-    // @todo: Make critical, first-run changes to the database here.
+
+    // Make sure that file.module is enabled as it is required for the user
+    // picture upgrade path.
+    update_module_enable(array('file'));
+
     update_variable_set('update_d8_requirements', TRUE);
   }
 }
diff --git a/core/modules/comment/comment.module b/core/modules/comment/comment.module
index e7007238c7a49652ae4983a5fc8262158b7ca5c0..38adbd06bb314d2c9daa2b60039be593f50cec85 100644
--- a/core/modules/comment/comment.module
+++ b/core/modules/comment/comment.module
@@ -1599,7 +1599,6 @@ function comment_preview(Comment $comment) {
       $comment->name = check_plain($account->name);
       $comment->signature = $account->signature;
       $comment->signature_format = $account->signature_format;
-      $comment->picture = $account->picture;
     }
     elseif (empty($comment->name)) {
       $comment->name = config('user.settings')->get('anonymous');
@@ -1655,7 +1654,14 @@ function template_preprocess_comment(&$variables) {
   $variables['changed'] = format_date($comment->changed);
 
   $variables['new'] = !empty($comment->new) ? t('new') : '';
-  $variables['user_picture'] = theme_get_setting('toggle_comment_user_picture') ? theme('user_picture', array('account' => $comment)) : '';
+  if (theme_get_setting('toggle_comment_user_picture')) {
+    // To change user picture settings (e.g., image style), edit the 'compact'
+    // view mode on the User entity.
+    $variables['user_picture'] = user_view($comment->account, 'compact');
+  }
+  else {
+    $variables['user_picture'] = array();
+  }
   $variables['signature'] = $comment->signature;
 
   $uri = $comment->uri();
diff --git a/core/modules/comment/lib/Drupal/comment/CommentRenderController.php b/core/modules/comment/lib/Drupal/comment/CommentRenderController.php
index c614f8efc8ce3d2449e9e1aea1ee97cf5aaccec1..bc21cd28dee2b81e941264392002305ccf615152 100644
--- a/core/modules/comment/lib/Drupal/comment/CommentRenderController.php
+++ b/core/modules/comment/lib/Drupal/comment/CommentRenderController.php
@@ -27,6 +27,9 @@ public function buildContent(array $entities = array(), $view_mode = 'full', $la
       return $return;
     }
 
+    // Attach user account.
+    user_attach_accounts($entities);
+
     parent::buildContent($entities, $view_mode, $langcode);
 
     foreach ($entities as $entity) {
diff --git a/core/modules/comment/lib/Drupal/comment/CommentStorageController.php b/core/modules/comment/lib/Drupal/comment/CommentStorageController.php
index 4d447a52ef27de527bb154045b5c69bbdd5f1513..50dde39a21ed44572504a0a2ea1ce63897eea2c3 100644
--- a/core/modules/comment/lib/Drupal/comment/CommentStorageController.php
+++ b/core/modules/comment/lib/Drupal/comment/CommentStorageController.php
@@ -34,7 +34,7 @@ protected function buildQuery($ids, $revision_id = FALSE) {
     $query->addField('n', 'type', 'node_type');
     $query->innerJoin('users', 'u', 'base.uid = u.uid');
     $query->addField('u', 'name', 'registered_name');
-    $query->fields('u', array('uid', 'signature', 'signature_format', 'picture'));
+    $query->fields('u', array('uid', 'signature', 'signature_format'));
     return $query;
   }
 
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentPreviewTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentPreviewTest.php
index 44a38d58081ba0670a794cc784944e91c42a1c48..07380761b243aefb4253d36d27202083366800e4 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentPreviewTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentPreviewTest.php
@@ -44,12 +44,11 @@ function testCommentPreview() {
     // Login as web user and add a signature and a user picture.
     $this->drupalLogin($this->web_user);
     config('user.settings')->set('signatures', 1)->save();
-    variable_set('user_pictures', 1);
     $test_signature = $this->randomName();
     $edit['signature[value]'] = '<a href="http://example.com/">' . $test_signature. '</a>';
     $edit['signature[format]'] = 'filtered_html';
     $image = current($this->drupalGetTestFiles('image'));
-    $edit['files[picture_upload]'] = drupal_realpath($image->uri);
+    $edit['files[user_picture_und_0]'] = drupal_realpath($image->uri);
     $this->drupalPost('user/' . $this->web_user->uid . '/edit', $edit, t('Save'));
 
     // As the web user, fill in the comment form and preview the comment.
diff --git a/core/modules/field/field.install b/core/modules/field/field.install
index bc566d6387841078dd177cdfcf076319483819f9..b88faa8b839d3b69190e0cdf97112f7a37d2dbc1 100644
--- a/core/modules/field/field.install
+++ b/core/modules/field/field.install
@@ -357,6 +357,15 @@ function _update_7000_field_create_instance($field, &$instance) {
     'deleted' => 0,
   );
 
+  // Merge in display defaults.
+  if (isset($instance['display'])) {
+    foreach ($instance['display'] as &$display) {
+      $display += array(
+        'weight' => 0,
+      );
+    }
+  }
+
   // The serialized 'data' column contains everything from $instance that does
   // not have its own column and is not automatically populated when the
   // instance is read.
diff --git a/core/modules/field/modules/field_sql_storage/field_sql_storage.install b/core/modules/field/modules/field_sql_storage/field_sql_storage.install
index 4d4fe57ea5de961fd26a47d7a65363057e743b91..9607a9c3af2d35e58c0399d3f6e8ee6c705d5e56 100644
--- a/core/modules/field/modules/field_sql_storage/field_sql_storage.install
+++ b/core/modules/field/modules/field_sql_storage/field_sql_storage.install
@@ -118,11 +118,15 @@ function field_sql_storage_update_8000(&$sandbox) {
     $table_info = array($data_table => $primary_key_data, $revision_table => $primary_key_revision);
 
     foreach ($table_info as $table => $primary_key) {
-      db_drop_primary_key($table);
-      db_drop_index($table, 'language');
-      db_change_field($table, 'language', 'langcode', $field_langcode);
-      db_add_primary_key($table, $primary_key);
-      db_add_index($table, 'langcode', $langcode_index);
+      // Do not attempt to rename the 'language' column for fields that already
+      // contain it (created during the upgrade before this update function).
+      if (db_field_exists($table, 'language')) {
+        db_drop_primary_key($table);
+        db_drop_index($table, 'language');
+        db_change_field($table, 'language', 'langcode', $field_langcode);
+        db_add_primary_key($table, $primary_key);
+        db_add_index($table, 'langcode', $langcode_index);
+      }
     }
   }
 }
diff --git a/core/modules/field_ui/field_ui.admin.inc b/core/modules/field_ui/field_ui.admin.inc
index c93aa03021b6631900d1dde921a121643092c190..c51a309c3145f34224b9940ba5b413e83cdd7417 100644
--- a/core/modules/field_ui/field_ui.admin.inc
+++ b/core/modules/field_ui/field_ui.admin.inc
@@ -455,6 +455,12 @@ function field_ui_widget_type_options($field_type = NULL, $by_label = FALSE) {
     $widget_types = field_info_widget_types();
     uasort($widget_types, 'drupal_sort_weight');
     foreach ($widget_types as $name => $widget_type) {
+      if (!isset($widget_type['field_types'])) {
+        // @todo: TestFieldWidgetMultiple widget is found but the info alter
+        //   hook isn't. Looks like another namespace problem. Ignore this entry
+        //   to allow the tests to pass. See http://drupal.org/node/1836008.
+        continue;
+      }
       foreach ($widget_type['field_types'] as $widget_field_type) {
         // Check that the field type exists.
         if (isset($field_types[$widget_field_type])) {
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php b/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
index 39324bfe7020a9b1b9d07e366023e9e993d02123..a67ad1f006eb9ff403513f2ac5add153f88c682c 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
@@ -32,6 +32,19 @@ function setUp() {
     $type_name = strtolower($this->randomName(8)) . '_test';
     $type = $this->drupalCreateContentType(array('name' => $type_name, 'type' => $type_name));
     $this->type = $type->type;
+
+    // Create a default vocabulary.
+    $vocabulary = entity_create('taxonomy_vocabulary', array(
+      'name' => $this->randomName(),
+      'description' => $this->randomName(),
+      'machine_name' => drupal_strtolower($this->randomName()),
+      'langcode' => LANGUAGE_NOT_SPECIFIED,
+      'help' => '',
+      'nodes' => array('article' => 'article'),
+      'weight' => mt_rand(0, 10),
+    ));
+    taxonomy_vocabulary_save($vocabulary);
+    $this->vocabulary = $vocabulary->machine_name;
   }
 
   /**
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageDisplayTest.php b/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageDisplayTest.php
index 6660782cb6b979dc599128e1af8528c3c3cfbf38..8396c7f238bdf5e2eb69f5ac993d28d2d55fdea8 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageDisplayTest.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageDisplayTest.php
@@ -192,11 +192,11 @@ function testNonInitializedFields() {
    * Tests hiding the view modes fieldset when there's only one available.
    */
   function testSingleViewMode() {
-    $this->drupalGet('admin/config/people/accounts/display');
+    $this->drupalGet('admin/structure/taxonomy/' . $this->vocabulary . '/display');
     $this->assertNoText('Use custom display settings for the following view modes', 'Custom display settings fieldset found.');
 
     // This may not trigger a notice when 'view_modes_custom' isn't available.
-    $this->drupalPost('admin/config/people/accounts/display', array(), t('Save'));
+    $this->drupalPost('admin/structure/taxonomy/' . $this->vocabulary . '/display', array(), t('Save'));
   }
 
   /**
diff --git a/core/modules/node/lib/Drupal/node/NodeRenderController.php b/core/modules/node/lib/Drupal/node/NodeRenderController.php
index 129f3253df86d86d47b87bd225b1f2f7fdb7abda..606722a1341233d738de5bfa81005fbd6cd24fa8 100644
--- a/core/modules/node/lib/Drupal/node/NodeRenderController.php
+++ b/core/modules/node/lib/Drupal/node/NodeRenderController.php
@@ -23,6 +23,10 @@ public function buildContent(array $entities = array(), $view_mode = 'full', $la
     if (empty($entities)) {
       return $return;
     }
+
+    // Attach user account.
+    user_attach_accounts($entities);
+
     parent::buildContent($entities, $view_mode, $langcode);
 
     foreach ($entities as $key => $entity) {
diff --git a/core/modules/node/node.module b/core/modules/node/node.module
index 08d781080a989e03279abe4812a51e31d8ce5c4b..71a57f2b388a6c4f71b22146ff5e112fa7bdd545 100644
--- a/core/modules/node/node.module
+++ b/core/modules/node/node.module
@@ -1148,7 +1148,14 @@ function template_preprocess_node(&$variables) {
   if (variable_get('node_submitted_' . $node->type, TRUE)) {
     $variables['display_submitted'] = TRUE;
     $variables['submitted'] = t('Submitted by !username on !datetime', array('!username' => $variables['name'], '!datetime' => $variables['date']));
-    $variables['user_picture'] = theme_get_setting('toggle_node_user_picture') ? theme('user_picture', array('account' => $node)) : '';
+    if (theme_get_setting('toggle_node_user_picture')) {
+      // To change user picture settings (e.g. image style), edit the 'compact'
+      // view mode on User entity.
+      $variables['user_picture'] = user_view($node->account, 'compact');
+    }
+    else {
+      $variables['user_picture'] = array();
+    }
   }
   else {
     $variables['display_submitted'] = FALSE;
diff --git a/core/modules/node/node.pages.inc b/core/modules/node/node.pages.inc
index a71f5eb0ea1747ff435a5bacb589476739f8ee48..71c72b8ddf30e84a5fc15ede401a5f3989de76b6 100644
--- a/core/modules/node/node.pages.inc
+++ b/core/modules/node/node.pages.inc
@@ -133,7 +133,6 @@ function node_preview(Node $node) {
       // user ID 0 denotes the anonymous user.
       if ($user = user_load_by_name($node->name)) {
         $node->uid = $user->uid;
-        $node->picture = $user->picture;
       }
       else {
         $node->uid = 0; // anonymous user
@@ -142,7 +141,6 @@ function node_preview(Node $node) {
     elseif ($node->uid) {
       $user = user_load($node->uid);
       $node->name = $user->name;
-      $node->picture = $user->picture;
     }
 
     $node->changed = REQUEST_TIME;
diff --git a/core/modules/system/lib/Drupal/system/Tests/Upgrade/UserPictureUpgradePathTest.php b/core/modules/system/lib/Drupal/system/Tests/Upgrade/UserPictureUpgradePathTest.php
new file mode 100644
index 0000000000000000000000000000000000000000..d86f7cde2c185c7ba6680bf7204c5087b3b845bb
--- /dev/null
+++ b/core/modules/system/lib/Drupal/system/Tests/Upgrade/UserPictureUpgradePathTest.php
@@ -0,0 +1,74 @@
+<?php
+
+/**
+ * @file
+ * Definition of Drupal\system\Tests\Upgrade\UserPictureUpgradePathTest.
+ */
+
+namespace Drupal\system\Tests\Upgrade;
+
+/**
+ * Tests upgrading a filled database with user picture data.
+ *
+ * Loads a filled installation of Drupal 7 with user picture data and runs the
+ * upgrade process on it.
+ */
+class UserPictureUpgradePathTest extends UpgradePathTestBase {
+
+  public static function getInfo() {
+    return array(
+      'name'  => 'User picture upgrade test',
+      'description'  => 'Upgrade tests with user picture data.',
+      'group' => 'Upgrade path',
+    );
+  }
+
+  public function setUp() {
+    $path = drupal_get_path('module', 'system') . '/tests/upgrade';
+    $this->databaseDumpFiles = array(
+      $path . '/drupal-7.bare.standard_all.database.php.gz',
+      $path . '/drupal-7.user_picture.database.php',
+    );
+    parent::setUp();
+  }
+
+  /**
+   * Tests expected user picture conversions after a successful upgrade.
+   */
+  public function testUserPictureUpgrade() {
+    $this->assertTrue($this->performUpgrade(), 'The upgrade was completed successfully.');
+
+    // Retrieve the field instance and check for migrated settings.
+    $instance = field_info_instance('user', 'user_picture', 'user');
+    $file = entity_load('file', $instance['settings']['default_image']);
+    $this->assertIdentical($instance['settings']['default_image'], $file->id(), 'Default user picture has been migrated.');
+    $this->assertEqual($file->uri, 'public://user_pictures_dir/druplicon.png', 'File id matches the uri expected.');
+    $this->assertEqual($file->filename, 'druplicon.png');
+    $this->assertEqual($file->langcode, LANGUAGE_NOT_SPECIFIED);
+    $this->assertEqual($file->filemime, 'image/png');
+    $this->assertFalse(empty($file->uuid));
+
+    // Check file usage for the default image.
+    $usage = file_usage()->listUsage($file);
+    $field = field_info_field('user_picture');
+    $this->assertEqual(1, $usage['image']['default_image'][$field['id']]);
+
+    $this->assertEqual($instance['settings']['max_resolution'], '800x800', 'User picture maximum resolution has been migrated.');
+    $this->assertEqual($instance['settings']['max_filesize'], '700 KB', 'User picture maximum filesize has been migrated.');
+    $this->assertEqual($instance['description'], 'These are user picture guidelines.', 'User picture guidelines are now the user picture field description.');
+    $this->assertEqual($instance['settings']['file_directory'], 'user_pictures_dir', 'User picture directory path has been migrated.');
+    $this->assertEqual($instance['display']['default']['settings']['image_style'], 'thumbnail', 'User picture image style setting has been migrated.');
+
+    // Verify compact view mode default settings.
+    $this->drupalGet('admin/config/people/accounts/display/compact');
+    $this->assertFieldByName('fields[member_for][type]', 'hidden');
+
+    // Check the user picture and file usage record.
+    $user = user_load(1);
+    $file = file_load($user->user_picture[LANGUAGE_NOT_SPECIFIED][0]['fid']);
+    $this->assertEqual('public://user_pictures_dir/faked_image.png', $file->uri);
+    $usage = file_usage()->listUsage($file);
+    $this->assertEqual(1, $usage['file']['user'][1]);
+  }
+
+}
diff --git a/core/modules/system/system.admin.inc b/core/modules/system/system.admin.inc
index d08c4ce0489e1c3e25f0bf0cdec48deadb4a7946..8c59d8280f9874b6c6e8161d0a758d97c27d07f2 100644
--- a/core/modules/system/system.admin.inc
+++ b/core/modules/system/system.admin.inc
@@ -409,7 +409,7 @@ function system_theme_settings($form, &$form_state, $key = '') {
 
   // Some features are not always available
   $disabled = array();
-  if (!variable_get('user_pictures', 0)) {
+  if (!user_picture_enabled()) {
     $disabled['toggle_node_user_picture'] = TRUE;
     $disabled['toggle_comment_user_picture'] = TRUE;
   }
diff --git a/core/modules/system/tests/upgrade/drupal-7.user_picture.database.php b/core/modules/system/tests/upgrade/drupal-7.user_picture.database.php
new file mode 100644
index 0000000000000000000000000000000000000000..12d2b2e6a830f6fe435f34ca35a7fb1a7dc97aee
--- /dev/null
+++ b/core/modules/system/tests/upgrade/drupal-7.user_picture.database.php
@@ -0,0 +1,89 @@
+<?php
+
+/**
+ * @file
+ * Database additions for user picture tests. Used in UserPictureUpgradePathTest.
+ *
+ * This dump only contains data and schema components relevant for user picture
+ * functionality. The drupal-7.bare.database.php file is imported before
+ * this dump, so the two form the database structure expected in tests
+ * altogether.
+ */
+
+// Add an image and assign it to uid 1.
+$fid = db_insert('file_managed')
+  ->fields(array(
+    'uri' => 'public://user_pictures_dir/faked_image.png',
+    'uid' => 1,
+    'status' => 1,
+    'filename' => 'faked_image.png',
+    'filesize' => 1000,
+    'filemime' => 'image/png',
+    'timestamp' => 1353542634,
+  ))
+  ->execute();
+
+db_insert('file_usage')
+  ->fields(array(
+    'fid' => $fid,
+    'module' => 'user',
+    'type' => 'user',
+    'id' => 1,
+    'count' => 1,
+  ))
+  ->execute();
+
+db_update('users')
+  ->condition('uid', 1)
+  ->fields(array(
+    'picture' => $fid,
+  ))
+  ->execute();
+
+// Set up variables needed for user picture support.
+$deleted_variables = array(
+  'user_pictures',
+  'user_picture_default',
+  'user_picture_dimensions',
+  'user_picture_file_size',
+  'user_picture_guidelines',
+  'user_picture_path',
+  'user_picture_style',
+);
+db_delete('variable')
+  ->condition('name', $deleted_variables, 'IN')
+  ->execute();
+
+db_insert('variable')->fields(array(
+  'name',
+  'value',
+))
+->values(array(
+  'name' => 'user_pictures',
+  'value' => 'i:1;',
+))
+->values(array(
+  'name' => 'user_picture_default',
+  'value' => 's:51:"sites/default/files/user_pictures_dir/druplicon.png";',
+))
+->values(array(
+  'name' => 'user_picture_dimensions',
+  'value' => 's:7:"800x800";',
+))
+->values(array(
+  'name' => 'user_picture_file_size',
+  'value' => 's:3:"700";',
+))
+->values(array(
+  'name' => 'user_picture_guidelines',
+  'value' => 's:34:"These are user picture guidelines.";',
+))
+->values(array(
+  'name' => 'user_picture_path',
+  'value' => 's:17:"user_pictures_dir";',
+))
+->values(array(
+  'name' => 'user_picture_style',
+  'value' => 's:9:"thumbnail";',
+))
+->execute();
diff --git a/core/modules/user/lib/Drupal/user/AccountFormController.php b/core/modules/user/lib/Drupal/user/AccountFormController.php
index b79e9830b223b9a344ee8ba46fb6e477c7b03170..30a6740a18aaddc2183ae010b5af7af2777e358f 100644
--- a/core/modules/user/lib/Drupal/user/AccountFormController.php
+++ b/core/modules/user/lib/Drupal/user/AccountFormController.php
@@ -171,39 +171,6 @@ public function form(array $form, array &$form_state, EntityInterface $account)
       '#format' => isset($account->signature_format) ? $account->signature_format : NULL,
     );
 
-    // Picture/avatar.
-    $form['picture'] = array(
-      '#type' => 'fieldset',
-      '#title' => t('Picture'),
-      '#weight' => 1,
-      '#access' => (!$register && variable_get('user_pictures', 0)),
-    );
-
-    $form['picture']['picture'] = array(
-      '#type' => 'value',
-      '#value' => isset($account->picture) ? $account->picture : NULL,
-    );
-
-    $form['picture']['picture_current'] = array(
-      '#markup' => theme('user_picture', array('account' => $account)),
-    );
-
-    $form['picture']['picture_delete'] = array(
-      '#type' => 'checkbox',
-      '#title' => t('Delete picture'),
-      '#access' => !empty($account->picture->fid),
-      '#description' => t('Check this box to delete your current picture.'),
-    );
-
-    $form['picture']['picture_upload'] = array(
-      '#type' => 'file',
-      '#title' => t('Upload picture'),
-      '#size' => 48,
-      '#description' => t('Your virtual face or picture. Pictures larger than @dimensions pixels will be scaled down.', array('@dimensions' => variable_get('user_picture_dimensions', '85x85'))) . ' ' . filter_xss_admin(variable_get('user_picture_guidelines', '')),
-    );
-
-    $form['#validate'][] = 'user_validate_picture';
-
     $user_preferred_langcode = $register ? $language_interface->langcode : user_preferred_langcode($account);
 
     $user_preferred_admin_langcode = $register ? $language_interface->langcode : user_preferred_langcode($account, 'admin');
diff --git a/core/modules/user/lib/Drupal/user/Plugin/Core/Entity/User.php b/core/modules/user/lib/Drupal/user/Plugin/Core/Entity/User.php
index dbedf89125800e748092e410f49f6a252c65df53..99aeac8c9dee52552a3a500fefcf31afacad9f33 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/Core/Entity/User.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/Core/Entity/User.php
@@ -47,7 +47,11 @@
  *     "full" = {
  *       "label" = "User account",
  *       "custom_settings" = FALSE
- *     }
+ *     },
+ *     "compact" = {
+         "label" = "Compact",
+         "custom_settings" = TRUE
+       }
  *   }
  * )
  */
@@ -167,13 +171,6 @@ class User extends Entity {
    */
   public $preferred_admin_langcode = LANGUAGE_NOT_SPECIFIED;
 
-  /**
-   * The file ID of the user's picture.
-   *
-   * @var integer
-   */
-  public $picture = 0;
-
   /**
    * The email address used for initial account creation.
    *
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/field/Picture.php b/core/modules/user/lib/Drupal/user/Plugin/views/field/Picture.php
deleted file mode 100644
index 8446facae6bc7ff964e0f012d3df26ed2e74a7a2..0000000000000000000000000000000000000000
--- a/core/modules/user/lib/Drupal/user/Plugin/views/field/Picture.php
+++ /dev/null
@@ -1,131 +0,0 @@
-<?php
-
-/**
- * @file
- * Definition of Drupal\user\Plugin\views\field\Picture.
- */
-
-namespace Drupal\user\Plugin\views\field;
-
-use Drupal\Core\Annotation\Plugin;
-use Drupal\views\ViewExecutable;
-use Drupal\views\Plugin\views\field\FieldPluginBase;
-
-/**
- * Field handler to provide simple renderer that allows using a themed user link.
- *
- * @ingroup views_field_handlers
- *
- * @Plugin(
- *   id = "user_picture",
- *   module = "user"
- * )
- */
-class Picture extends FieldPluginBase {
-
-  /**
-   * Overrides Drupal\views\Plugin\views\field\FieldPluginBase::init().
-   */
-  public function init(ViewExecutable $view, &$options) {
-    parent::init($view, $options);
-
-    $this->additional_fields['uid'] = 'uid';
-    $this->additional_fields['name'] = 'name';
-    $this->additional_fields['mail'] = 'mail';
-  }
-
-  function element_type($none_supported = FALSE, $default_empty = FALSE, $inline = FALSE) {
-    if ($inline) {
-      return 'span';
-    }
-    if ($none_supported) {
-      if ($this->options['element_type'] === '0') {
-        return '';
-      }
-    }
-    if ($this->options['element_type']) {
-      return check_plain($this->options['element_type']);
-    }
-    if ($default_empty) {
-      return '';
-    }
-    if (isset($this->definition['element type'])) {
-      return $this->definition['element type'];
-    }
-
-    return 'div';
-  }
-
-  protected function defineOptions() {
-    $options = parent::defineOptions();
-    $options['link_photo_to_profile'] = array('default' => TRUE, 'bool' => TRUE);
-    $options['image_style'] = array('default' => '');
-    return $options;
-  }
-
-  public function buildOptionsForm(&$form, &$form_state) {
-    parent::buildOptionsForm($form, $form_state);
-    $form['link_photo_to_profile'] = array(
-      '#title' => t("Link to user's profile"),
-      '#description' => t("Link the user picture to the user's profile"),
-      '#type' => 'checkbox',
-      '#default_value' => $this->options['link_photo_to_profile'],
-    );
-
-    if (module_exists('image')) {
-      $styles = image_styles();
-      $style_options = array('' => t('Default'));
-      foreach ($styles as $style) {
-        $style_options[$style['name']] = $style['name'];
-      }
-
-      $form['image_style'] = array(
-        '#title' => t('Image style'),
-        '#description' => t('Using <em>Default</em> will use the site-wide image style for user pictures set in the <a href="!account-settings">Account settings</a>.', array('!account-settings' => url('admin/config/people/accounts', array('fragment' => 'edit-personalization')))),
-        '#type' => 'select',
-        '#options' => $style_options,
-        '#default_value' => $this->options['image_style'],
-      );
-    }
-  }
-
-  function render($values) {
-    if ($this->options['image_style'] && module_exists('image')) {
-      // @todo: Switch to always using theme('user_picture') when it starts
-      // supporting image styles. See http://drupal.org/node/1021564
-      if ($picture_fid = $this->get_value($values)) {
-        $picture = file_load($picture_fid);
-        $picture_filepath = $picture->uri;
-      }
-      else {
-        $picture_filepath = variable_get('user_picture_default', '');
-      }
-      if (file_valid_uri($picture_filepath)) {
-        $output = theme('image_style', array('style_name' => $this->options['image_style'], 'path' => $picture_filepath));
-        if ($this->options['link_photo_to_profile'] && user_access('access user profiles')) {
-          $uid = $this->get_value($values, 'uid');
-          $output = l($output, "user/$uid", array('html' => TRUE));
-        }
-      }
-      else {
-        $output = '';
-      }
-    }
-    else {
-      // Fake an account object.
-      $account = entity_create('user', array());
-      if ($this->options['link_photo_to_profile']) {
-        // Prevent template_preprocess_user_picture from adding a link
-        // by not setting the uid.
-        $account->uid = $this->get_value($values, 'uid');
-      }
-      $account->name = $this->get_value($values, 'name');
-      $account->mail = $this->get_value($values, 'mail');
-      $account->picture = $this->get_value($values);
-      $output = theme('user_picture', array('account' => $account));
-    }
-
-    return $output;
-  }
-
-}
diff --git a/core/modules/user/lib/Drupal/user/Tests/UserEditTest.php b/core/modules/user/lib/Drupal/user/Tests/UserEditTest.php
index ea78e033c6ed5a054afd30dfbe58e4d57f93f1df..0cd38e4fa1ebd20d33c684f31d7ab4faa99260c1 100644
--- a/core/modules/user/lib/Drupal/user/Tests/UserEditTest.php
+++ b/core/modules/user/lib/Drupal/user/Tests/UserEditTest.php
@@ -26,8 +26,7 @@ public static function getInfo() {
    * Test user edit page.
    */
   function testUserEdit() {
-    // Test user edit functionality with user pictures disabled.
-    variable_set('user_pictures', 0);
+    // Test user edit functionality.
     $user1 = $this->drupalCreateUser(array('change own username'));
     $user2 = $this->drupalCreateUser(array());
     $this->drupalLogin($user1);
@@ -37,11 +36,6 @@ function testUserEdit() {
     $this->drupalPost("user/$user1->uid/edit", $edit, t('Save'));
     $this->assertRaw(t('The name %name is already taken.', array('%name' => $edit['name'])));
 
-    // Repeat the test with user pictures enabled, which modifies the form.
-    variable_set('user_pictures', 1);
-    $this->drupalPost("user/$user1->uid/edit", $edit, t('Save'));
-    $this->assertRaw(t('The name %name is already taken.', array('%name' => $edit['name'])));
-
     // Check that filling out a single password field does not validate.
     $edit = array();
     $edit['pass[pass1]'] = '';
diff --git a/core/modules/user/lib/Drupal/user/Tests/UserPictureTest.php b/core/modules/user/lib/Drupal/user/Tests/UserPictureTest.php
index 0413b3b0b0700fd9db5dc2ff254f348f214a49c4..26545d8d7f187b8b13b7be2ca0de6102da4055f1 100644
--- a/core/modules/user/lib/Drupal/user/Tests/UserPictureTest.php
+++ b/core/modules/user/lib/Drupal/user/Tests/UserPictureTest.php
@@ -9,6 +9,9 @@
 
 use Drupal\simpletest\WebTestBase;
 
+/**
+ * Tests user picture functionality.
+ */
 class UserPictureTest extends WebTestBase {
 
   /**
@@ -16,312 +19,117 @@ class UserPictureTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('image');
+  public static $modules = array('image', 'comment');
 
   protected $user;
   protected $_directory_test;
 
   public static function getInfo() {
     return array(
-      'name' => 'Upload user picture',
-      'description' => 'Assure that dimension check, extension check and image scaling work as designed.',
-      'group' => 'User'
+      'name' => 'User pictures',
+      'description' => 'Tests user picture functionality.',
+      'group' => 'User',
     );
   }
 
   function setUp() {
     parent::setUp();
 
-    // Enable user pictures.
-    variable_set('user_pictures', 1);
-
-    // Configure default user picture settings.
-    variable_set('user_picture_dimensions', '1024x1024');
-    variable_set('user_picture_file_size', '800');
-    variable_set('user_picture_style', 'thumbnail');
-
-    $this->user = $this->drupalCreateUser();
-
-    // Test if directories specified in settings exist in filesystem.
-    $file_dir = 'public://';
-    $file_check = file_prepare_directory($file_dir, FILE_CREATE_DIRECTORY);
-    // TODO: Test public and private methods?
-
-    $picture_dir = variable_get('user_picture_path', 'pictures');
-    $picture_path = $file_dir . $picture_dir;
-
-    $pic_check = file_prepare_directory($picture_path, FILE_CREATE_DIRECTORY);
-    $this->_directory_test = is_writable($picture_path);
-    $this->assertTrue($this->_directory_test, "The directory $picture_path doesn't exist or is not writable. Further tests won't be made.");
-  }
-
-  function testNoPicture() {
-    $this->drupalLogin($this->user);
-
-    // Try to upload a file that is not an image for the user picture.
-    $not_an_image = current($this->drupalGetTestFiles('html'));
-    $this->saveUserPicture($not_an_image);
-    $this->assertRaw(t('Only JPEG, PNG and GIF images are allowed.'), 'Non-image files are not accepted.');
-  }
-
-  /**
-   * Do the test:
-   *  GD Toolkit is installed
-   *  Picture has invalid dimension
-   *
-   * results: The image should be uploaded because ImageGDToolkit resizes the picture
-   */
-  function testWithGDinvalidDimension() {
-    if ($this->_directory_test && image_get_toolkit()) {
-      $this->drupalLogin($this->user);
-
-      $image = current($this->drupalGetTestFiles('image'));
-      $info = image_get_info($image->uri);
-
-      // Set new variables: invalid dimensions, valid filesize (0 = no limit).
-      $test_dim = ($info['width'] - 10) . 'x' . ($info['height'] - 10);
-      variable_set('user_picture_dimensions', $test_dim);
-      variable_set('user_picture_file_size', 0);
-
-      $pic_path = $this->saveUserPicture($image);
-      // Check that the image was resized and is being displayed on the
-      // user's profile page.
-      $text = t('The image was resized to fit within the maximum allowed dimensions of %dimensions pixels.', array('%dimensions' => $test_dim));
-      $this->assertRaw($text, 'Image was resized.');
-      $alt = t("@user's picture", array('@user' => user_format_name($this->user)));
-      $style = variable_get('user_picture_style', '');
-      $this->assertRaw(image_style_url($style, $pic_path), "Image is displayed in user's edit page");
-
-      // Check if file is located in proper directory.
-      $this->assertTrue(is_file($pic_path), 'File is located in proper directory.');
-    }
-  }
-
-  /**
-   * Do the test:
-   *  GD Toolkit is installed
-   *  Picture has invalid size
-   *
-   * results: The image should be uploaded because ImageGDToolkit resizes the picture
-   */
-  function testWithGDinvalidSize() {
-    if ($this->_directory_test && image_get_toolkit()) {
-      $this->drupalLogin($this->user);
-
-      // Images are sorted first by size then by name. We need an image
-      // bigger than 1 KB so we'll grab the last one.
-      $files = $this->drupalGetTestFiles('image');
-      $image = end($files);
-      $info = image_get_info($image->uri);
-
-      // Set new variables: valid dimensions, invalid filesize.
-      $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
-      $test_size = 1;
-      variable_set('user_picture_dimensions', $test_dim);
-      variable_set('user_picture_file_size', $test_size);
-
-      $pic_path = $this->saveUserPicture($image);
-
-      // Test that the upload failed and that the correct reason was cited.
-      $text = t('The specified file %filename could not be uploaded.', array('%filename' => $image->filename));
-      $this->assertRaw($text, 'Upload failed.');
-      $text = t('The file is %filesize exceeding the maximum file size of %maxsize.', array('%filesize' => format_size(filesize($image->uri)), '%maxsize' => format_size($test_size * 1024)));
-      $this->assertRaw($text, 'File size cited as reason for failure.');
-
-      // Check if file is not uploaded.
-      $this->assertFalse(is_file($pic_path), 'File was not uploaded.');
-    }
-  }
-
-  /**
-   * Do the test:
-   *  GD Toolkit is not installed
-   *  Picture has invalid size
-   *
-   * results: The image shouldn't be uploaded
-   */
-  function testWithoutGDinvalidDimension() {
-    if ($this->_directory_test && !image_get_toolkit()) {
-      $this->drupalLogin($this->user);
-
-      $image = current($this->drupalGetTestFiles('image'));
-      $info = image_get_info($image->uri);
-
-      // Set new variables: invalid dimensions, valid filesize (0 = no limit).
-      $test_dim = ($info['width'] - 10) . 'x' . ($info['height'] - 10);
-      variable_set('user_picture_dimensions', $test_dim);
-      variable_set('user_picture_file_size', 0);
-
-      $pic_path = $this->saveUserPicture($image);
-
-      // Test that the upload failed and that the correct reason was cited.
-      $text = t('The specified file %filename could not be uploaded.', array('%filename' => $image->filename));
-      $this->assertRaw($text, 'Upload failed.');
-      $text = t('The image is too large; the maximum dimensions are %dimensions pixels.', array('%dimensions' => $test_dim));
-      $this->assertRaw($text, 'Checking response on invalid image (dimensions).');
-
-      // Check if file is not uploaded.
-      $this->assertFalse(is_file($pic_path), 'File was not uploaded.');
-    }
-  }
-
-  /**
-   * Do the test:
-   *  GD Toolkit is not installed
-   *  Picture has invalid size
-   *
-   * results: The image shouldn't be uploaded
-   */
-  function testWithoutGDinvalidSize() {
-    if ($this->_directory_test && !image_get_toolkit()) {
-      $this->drupalLogin($this->user);
-
-      $image = current($this->drupalGetTestFiles('image'));
-      $info = image_get_info($image->uri);
-
-      // Set new variables: valid dimensions, invalid filesize.
-      $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
-      $test_size = 1;
-      variable_set('user_picture_dimensions', $test_dim);
-      variable_set('user_picture_file_size', $test_size);
-
-      $pic_path = $this->saveUserPicture($image);
-
-      // Test that the upload failed and that the correct reason was cited.
-      $text = t('The specified file %filename could not be uploaded.', array('%filename' => $image->filename));
-      $this->assertRaw($text, 'Upload failed.');
-      $text = t('The file is %filesize exceeding the maximum file size of %maxsize.', array('%filesize' => format_size(filesize($image->uri)), '%maxsize' => format_size($test_size * 1024)));
-      $this->assertRaw($text, 'File size cited as reason for failure.');
-
-      // Check if file is not uploaded.
-      $this->assertFalse(is_file($pic_path), 'File was not uploaded.');
-    }
+    $this->web_user = $this->drupalCreateUser(array(
+      'access content',
+      'access comments',
+      'post comments',
+      'skip comment approval',
+    ));
+    $this->drupalCreateContentType(array('type' => 'article', 'name' => 'Article'));
+
+    // @see standard.install
+    module_load_install('user');
+    _user_install_picture_field();
+
+    // Remove 'summary' pseudo-field from compact view mode on the User entity.
+    $bundle_settings = field_bundle_settings('user', 'user');
+    $bundle_settings['extra_fields']['display']['member_for']['compact'] = array(
+      'visible' => FALSE,
+      'weight' => 10,
+    );
+    field_bundle_settings('user', 'user', $bundle_settings);
   }
 
   /**
-   * Do the test:
-   *  Picture is valid (proper size and dimension)
-   *
-   * results: The image should be uploaded
+   * Tests creation, display, and deletion of user pictures.
    */
-  function testPictureIsValid() {
-    if ($this->_directory_test) {
-      $this->drupalLogin($this->user);
-
-      $image = current($this->drupalGetTestFiles('image'));
-      $info = image_get_info($image->uri);
-
-      // Set new variables: valid dimensions, valid filesize (0 = no limit).
-      $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
-      variable_set('user_picture_dimensions', $test_dim);
-      variable_set('user_picture_file_size', 0);
-
-      $pic_path = $this->saveUserPicture($image);
-
-      // Check if image is displayed in user's profile page.
-      $this->drupalGet('user');
-      $this->assertRaw(file_uri_target($pic_path), "Image is displayed in user's profile page.");
+  function testCreateDeletePicture() {
+    $this->drupalLogin($this->web_user);
 
-      // Check if file is located in proper directory.
-      $this->assertTrue(is_file($pic_path), 'File is located in proper directory.');
-
-      // Set new picture dimensions.
-      $test_dim = ($info['width'] + 5) . 'x' . ($info['height'] + 5);
-      variable_set('user_picture_dimensions', $test_dim);
-
-      $pic_path2 = $this->saveUserPicture($image);
-      $this->assertNotEqual($pic_path, $pic_path2, 'Filename of second picture is different.');
-    }
-  }
-
-  /**
-   * Test HTTP schema working with user pictures.
-   */
-  function testExternalPicture() {
-    $this->drupalLogin($this->user);
-    // Set the default picture to an URI with a HTTP schema.
-    $images = $this->drupalGetTestFiles('image');
-    $image = $images[0];
-    $pic_path = file_create_url($image->uri);
-    variable_set('user_picture_default', $pic_path);
+    // Save a new picture.
+    $image = current($this->drupalGetTestFiles('image'));
+    $file = $this->saveUserPicture($image);
 
-    // Check if image is displayed in user's profile page.
+    // Verify that the image is displayed on the user account page.
     $this->drupalGet('user');
-
-    // Get the user picture image via xpath.
-    $elements = $this->xpath('//div[@class="user-picture"]/img');
-    $this->assertEqual(count($elements), 1, "There is exactly one user picture on the user's profile page.");
-    $this->assertEqual($pic_path, (string) $elements[0]['src'], format_string("User picture source is correct: %path %elements.", array('%path' => $pic_path, '%elements' => print_r($elements, TRUE))));
+    $this->assertRaw(file_uri_target($file->uri), 'User picture found on user account page.');
+
+    // Delete the picture.
+    $edit = array();
+    $this->drupalPost('user/' . $this->web_user->uid . '/edit', $edit, t('Remove'));
+    $this->drupalPost(NULL, array(), t('Save'));
+
+    // Call system_cron() to clean up the file. Make sure the timestamp
+    // of the file is older than DRUPAL_MAXIMUM_TEMP_FILE_AGE.
+    db_update('file_managed')
+      ->fields(array(
+        'timestamp' => REQUEST_TIME - (DRUPAL_MAXIMUM_TEMP_FILE_AGE + 1),
+      ))
+      ->condition('fid', $file->fid)
+      ->execute();
+    drupal_cron_run();
+
+    // Verify that the image has been deleted.
+    $this->assertFalse(file_load($file->fid), 'File was removed from the database.');
+    // Clear out PHP's file stat cache so we see the current value.
+    clearstatcache(TRUE, $file->uri);
+    $this->assertFalse(is_file($file->uri), 'File was removed from the file system.');
   }
 
   /**
-   * Tests deletion of user pictures.
+   * Tests embedded users on node pages.
    */
-  function testDeletePicture() {
-    $this->drupalLogin($this->user);
-
-    $image = current($this->drupalGetTestFiles('image'));
-    $info = image_get_info($image->uri);
-
-    // Set new variables: valid dimensions, valid filesize (0 = no limit).
-    $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
-    variable_set('user_picture_dimensions', $test_dim);
-    variable_set('user_picture_file_size', 0);
+  function testPictureOnNodeComment() {
+    $this->drupalLogin($this->web_user);
 
     // Save a new picture.
-    $edit = array('files[picture_upload]' => drupal_realpath($image->uri));
-    $this->drupalPost('user/' . $this->user->uid . '/edit', $edit, t('Save'));
-
-    // Load actual user data from database.
-    $account = user_load($this->user->uid, TRUE);
-    $pic_path = !empty($account->picture) ? $account->picture->uri : NULL;
-
-    // Check if image is displayed in user's profile page.
-    $this->drupalGet('user');
-    $this->assertRaw(file_uri_target($pic_path), "Image is displayed in user's profile page");
-
-    // Check if file is located in proper directory.
-    $this->assertTrue(is_file($pic_path), 'File is located in proper directory');
+    $image = current($this->drupalGetTestFiles('image'));
+    $file = $this->saveUserPicture($image);
 
-    $edit = array('picture_delete' => 1);
-    $this->drupalPost('user/' . $this->user->uid . '/edit', $edit, t('Save'));
+    $node = $this->drupalCreateNode(array('type' => 'article'));
 
-    // Load actual user data from database.
-    $account1 = user_load($this->user->uid, TRUE);
-    $this->assertFalse($account1->picture, 'User object has no picture');
+    // Enable user pictures on nodes.
+    variable_set('theme_settings', array('toggle_node_user_picture' => TRUE));
 
-    $file = file_load($account->picture->fid);
-    $this->assertFalse($file, 'File is removed from database');
+    // Verify that the image is displayed on the user account page.
+    $this->drupalGet('node/' . $node->nid);
+    $this->assertRaw(file_uri_target($file->uri), 'User picture found on node page.');
 
-    // Clear out PHP's file stat cache so we see the current value.
-    clearstatcache(TRUE, $pic_path);
-    $this->assertFalse(is_file($pic_path), 'File is removed from file system');
-  }
+    // Enable user pictures on comments, instead of nodes.
+    variable_set('theme_settings', array('toggle_comment_user_picture' => TRUE));
 
-  function saveUserPicture($image) {
-    $edit = array('files[picture_upload]' => drupal_realpath($image->uri));
-    $this->drupalPost('user/' . $this->user->uid . '/edit', $edit, t('Save'));
-
-    // Load actual user data from database.
-    $account = user_load($this->user->uid, TRUE);
-    return !empty($account->picture) ? $account->picture->uri : NULL;
+    $edit = array(
+      'comment_body[' . LANGUAGE_NOT_SPECIFIED . '][0][value]' => $this->randomString(),
+    );
+    $this->drupalPost('comment/reply/' . $node->nid, $edit, t('Save'));
+    $this->assertRaw(file_uri_target($file->uri), 'User picture found on comment.');
   }
 
   /**
-   * Tests the admin form validates user picture settings.
+   * Edits the user picture for the test user.
    */
-  function testUserPictureAdminFormValidation() {
-    $this->drupalLogin($this->drupalCreateUser(array('administer users')));
-
-    // The default values are valid.
-    $this->drupalPost('admin/config/people/accounts', array(), t('Save configuration'));
-    $this->assertText(t('The configuration options have been saved.'), 'The default values are valid.');
+  function saveUserPicture($image) {
+    $edit = array('files[user_picture_und_0]' => drupal_realpath($image->uri));
+    $this->drupalPost('user/' . $this->web_user->uid . '/edit', $edit, t('Save'));
 
-    // The form does not save with an invalid file size.
-    $edit = array(
-      'user_picture_file_size' => $this->randomName(),
-    );
-    $this->drupalPost('admin/config/people/accounts', $edit, t('Save configuration'));
-    $this->assertNoText(t('The configuration options have been saved.'), 'The form does not save with an invalid file size.');
+    // Load actual user data from database.
+    $account = user_load($this->web_user->uid, TRUE);
+    return file_load($account->user_picture[LANGUAGE_NOT_SPECIFIED][0]['fid']);
   }
 }
diff --git a/core/modules/user/lib/Drupal/user/Tests/UserRegistrationTest.php b/core/modules/user/lib/Drupal/user/Tests/UserRegistrationTest.php
index 9c518d708c12436e9921cb0c1b12728cfa872357..73f3396871527ebfefffe1649e3fcc9856a11095 100644
--- a/core/modules/user/lib/Drupal/user/Tests/UserRegistrationTest.php
+++ b/core/modules/user/lib/Drupal/user/Tests/UserRegistrationTest.php
@@ -185,7 +185,6 @@ function testRegistrationDefaultValues() {
     $this->assertEqual($new_user->timezone, variable_get('date_default_timezone'), 'Correct time zone field.');
     $this->assertEqual($new_user->langcode, language_default()->langcode, 'Correct language field.');
     $this->assertEqual($new_user->preferred_langcode, language_default()->langcode, 'Correct preferred language field.');
-    $this->assertEqual($new_user->picture, 0, 'Correct picture field.');
     $this->assertEqual($new_user->init, $mail, 'Correct init field.');
   }
 
diff --git a/core/modules/user/lib/Drupal/user/UserStorageController.php b/core/modules/user/lib/Drupal/user/UserStorageController.php
index ca47505afeefb5681f994df021bc76dc3fa4273c..cf0322d33fb44e994336d5c6a343ed7ba56e6956 100644
--- a/core/modules/user/lib/Drupal/user/UserStorageController.php
+++ b/core/modules/user/lib/Drupal/user/UserStorageController.php
@@ -23,12 +23,7 @@ class UserStorageController extends DatabaseStorageController {
    * Overrides Drupal\Core\Entity\DatabaseStorageController::attachLoad().
    */
   function attachLoad(&$queried_users, $load_revision = FALSE) {
-    // Build an array of user picture IDs so that these can be fetched later.
-    $picture_fids = array();
     foreach ($queried_users as $key => $record) {
-      if ($record->picture) {
-        $picture_fids[] = $record->picture;
-      }
       $queried_users[$key]->data = unserialize($record->data);
       $queried_users[$key]->roles = array();
       if ($record->uid) {
@@ -45,15 +40,6 @@ function attachLoad(&$queried_users, $load_revision = FALSE) {
       $queried_users[$record->uid]->roles[$record->rid] = $record->name;
     }
 
-    // Add the full file objects for user pictures if enabled.
-    if (!empty($picture_fids) && variable_get('user_pictures', 1) == 1) {
-      $pictures = file_load_multiple($picture_fids);
-      foreach ($queried_users as $entity) {
-        if (!empty($entity->picture) && isset($pictures[$entity->picture])) {
-          $entity->picture = $pictures[$entity->picture];
-        }
-      }
-    }
     // Call the default attachLoad() method. This will add fields and call
     // hook_user_load().
     parent::attachLoad($queried_users, $load_revision);
@@ -97,45 +83,7 @@ protected function preSave(EntityInterface $entity) {
       }
     }
 
-    if (!empty($entity->picture_upload)) {
-      $entity->picture = $entity->picture_upload;
-    }
-    // Delete the picture if the submission indicates that it should be deleted
-    // and no replacement was submitted.
-    elseif (!empty($entity->picture_delete)) {
-      $entity->picture = 0;
-      file_usage()->delete($entity->original->picture, 'user', 'user', $entity->uid);
-      file_delete($entity->original->picture->fid);
-    }
-
     if (!$entity->isNew()) {
-      // Process picture uploads.
-      if (!empty($entity->picture->fid) && (!isset($entity->original->picture->fid) || $entity->picture->fid != $entity->original->picture->fid)) {
-        $picture = $entity->picture;
-        // If the picture is a temporary file, move it to its final location
-        // and make it permanent.
-        if (!$picture->status) {
-          $info = image_get_info($picture->uri);
-          $picture_directory =  file_default_scheme() . '://' . variable_get('user_picture_path', 'pictures');
-
-          // Prepare the pictures directory.
-          file_prepare_directory($picture_directory, FILE_CREATE_DIRECTORY);
-          $destination = file_stream_wrapper_uri_normalize($picture_directory . '/picture-' . $entity->uid . '-' . REQUEST_TIME . '.' . $info['extension']);
-
-          // Move the temporary file into the final location.
-          if ($picture = file_move($picture, $destination, FILE_EXISTS_RENAME)) {
-            $entity->picture = $picture;
-            file_usage()->add($picture, 'user', 'user', $entity->uid);
-          }
-        }
-        // Delete the previous picture if it was deleted or replaced.
-        if (!empty($entity->original->picture->fid)) {
-          file_usage()->delete($entity->original->picture, 'user', 'user', $entity->uid);
-          file_delete($entity->original->picture->fid);
-        }
-      }
-      $entity->picture = empty($entity->picture->fid) ? 0 : $entity->picture->fid;
-
       // If the password is empty, that means it was not changed, so use the
       // original password.
       if (empty($entity->pass)) {
diff --git a/core/modules/user/templates/user-profile.tpl.php b/core/modules/user/templates/user-profile.tpl.php
index a7bca78eb123847ec44b654b1f06d12279a1ad99..dd9eb7809a0f91ae1a15b3e887f0570c8c093eae 100644
--- a/core/modules/user/templates/user-profile.tpl.php
+++ b/core/modules/user/templates/user-profile.tpl.php
@@ -8,12 +8,10 @@
  * e.g., example.com/user/123. 123 being the users ID.
  *
  * Use render($user_profile) to print all profile items, or print a subset
- * such as render($user_profile['user_picture']). Always call
- * render($user_profile) at the end in order to print all remaining items. If
- * the item is a category, it will contain all its profile items. By default,
- * $user_profile['member_for'] is provided, which contains data on the user's
- * history. Other data can be included by modules. $user_profile['user_picture']
- * is available for showing the account picture.
+ * such as render($content['field_example']).
+ * If the item is a category, it will contain all its profile items. By default,
+ * $user_profile['summary'] is provided, which contains data on the user's
+ * history. Other data can be included by modules.
  *
  * Available variables:
  *   - $user_profile: An array of profile items. Use render() to print them.
diff --git a/core/modules/user/user-rtl.css b/core/modules/user/user-rtl.css
index 5a1442c1c5104f68da55bac4014ee126777c69c5..ec459b4d9bba45ea916e0abb1e52849661afd96b 100644
--- a/core/modules/user/user-rtl.css
+++ b/core/modules/user/user-rtl.css
@@ -20,9 +20,3 @@ div.password-confirm {
 .password-parent {
   clear: right;
 }
-
-/* Generated by user.module but used by profile.module: */
-.profile .user-picture {
-  float: left;
-  margin: 0 0 1em 1em;
-}
diff --git a/core/modules/user/user.admin.inc b/core/modules/user/user.admin.inc
index bab307b766d1820392bce96d4a2814cff4ef79a7..277164ad9440c6867bc3d4502dfb58c645d93649 100644
--- a/core/modules/user/user.admin.inc
+++ b/core/modules/user/user.admin.inc
@@ -376,78 +376,6 @@ function user_admin_settings($form, &$form_state) {
     '#title' => t('Enable signatures.'),
     '#default_value' => $config->get('signatures'),
   );
-  // If picture support is enabled, check whether the picture directory exists.
-  if (variable_get('user_pictures', 0)) {
-    $picture_path =  file_default_scheme() . '://' . variable_get('user_picture_path', 'pictures');
-    if (!file_prepare_directory($picture_path, FILE_CREATE_DIRECTORY)) {
-      form_set_error('user_picture_path', t('The directory %directory does not exist or is not writable.', array('%directory' => $picture_path)));
-      watchdog('file system', 'The directory %directory does not exist or is not writable.', array('%directory' => $picture_path), WATCHDOG_ERROR);
-    }
-  }
-  $picture_support = variable_get('user_pictures', 0);
-  $form['personalization']['user_pictures'] = array(
-    '#type' => 'checkbox',
-    '#title' => t('Enable user pictures.'),
-    '#default_value' => $picture_support,
-  );
-  $form['#attached']['library'][] = array('user', 'drupal.user');
-  $form['personalization']['pictures'] = array(
-    '#type' => 'container',
-    '#states' => array(
-      // Hide the additional picture settings when user pictures are disabled.
-      'invisible' => array(
-        'input[name="user_pictures"]' => array('checked' => FALSE),
-      ),
-    ),
-  );
-  $form['personalization']['pictures']['user_picture_path'] = array(
-    '#type' => 'textfield',
-    '#title' => t('Picture directory'),
-    '#default_value' => variable_get('user_picture_path', 'pictures'),
-    '#size' => 30,
-    '#maxlength' => 255,
-    '#description' => t('Subdirectory in the file upload directory where pictures will be stored.'),
-  );
-  $form['personalization']['pictures']['user_picture_default'] = array(
-    '#type' => 'textfield',
-    '#title' => t('Default picture'),
-    '#default_value' => variable_get('user_picture_default', ''),
-    '#size' => 30,
-    '#maxlength' => 255,
-    '#description' => t('URL of picture to display for users with no custom picture selected. Leave blank for none.'),
-  );
-  if (module_exists('image')) {
-    $form['personalization']['pictures']['settings']['user_picture_style'] = array(
-      '#type' => 'select',
-      '#title' => t('Picture display style'),
-      '#options' => image_style_options(TRUE),
-      '#default_value' => variable_get('user_picture_style', ''),
-      '#description' => t('The style selected will be used on display, while the original image is retained. Styles may be configured in the <a href="!url">Image styles</a> administration area.', array('!url' => url('admin/config/media/image-styles'))),
-    );
-  }
-  $form['personalization']['pictures']['user_picture_dimensions'] = array(
-    '#type' => 'textfield',
-    '#title' => t('Picture upload dimensions'),
-    '#default_value' => variable_get('user_picture_dimensions', '85x85'),
-    '#size' => 10,
-    '#maxlength' => 10,
-    '#field_suffix' => ' ' . t('pixels'),
-    '#description' => t('Pictures larger than this will be scaled down to this size.'),
-  );
-  $form['personalization']['pictures']['user_picture_file_size'] = array(
-    '#type' => 'number',
-    '#title' => t('Picture upload file size'),
-    '#default_value' => variable_get('user_picture_file_size', '30'),
-    '#min' => 0,
-    '#field_suffix' => ' ' . t('KB'),
-    '#description' => t('Maximum allowed file size for uploaded pictures. Upload size is normally limited only by the PHP maximum post and file upload settings, and images are automatically scaled down to the dimensions specified above.'),
-  );
-  $form['personalization']['pictures']['user_picture_guidelines'] = array(
-    '#type' => 'textarea',
-    '#title' => t('Picture guidelines'),
-    '#default_value' => variable_get('user_picture_guidelines', ''),
-    '#description' => t("This text is displayed at the picture upload form in addition to the default guidelines. It's useful for helping or instructing your users."),
-  );
 
   $form['email_title'] = array(
     '#type' => 'item',
diff --git a/core/modules/user/user.api.php b/core/modules/user/user.api.php
index 8714d16ee09b34a45148af8162746fb42c883856..cb7b4e5f64b0f7718fd3738f3bcf3830450ab04f 100644
--- a/core/modules/user/user.api.php
+++ b/core/modules/user/user.api.php
@@ -349,12 +349,17 @@ function hook_user_logout($account) {
  * @see hook_entity_view()
  */
 function hook_user_view($account, $view_mode, $langcode) {
-  $account->content['user_picture'] = array(
-    '#markup' => theme('user_picture', array('account' => $account)),
-    '#weight' => -10,
+  if (!isset($account->content['summary'])) {
+    $account->content['summary'] = array();
+  }
+  $account->content['summary'] += array(
+    '#type' => 'user_profile_category',
+    '#title' => t('History'),
+    '#attributes' => array('class' => array('user-member')),
+    '#weight' => 5,
   );
-  $account->content['member_for'] = array(
-    '#type' => 'item',
+  $account->content['summary']['member_for'] = array(
+    '#type' => 'user_profile_item',
     '#title' => t('Member for'),
     '#markup' => format_interval(REQUEST_TIME - $account->created),
   );
diff --git a/core/modules/user/user.css b/core/modules/user/user.css
index a54a5d0163ec33e09e6cacd75f0c6f56db180768..28aa37360cb1ea83ed18727c522c3fafca8a3d81 100644
--- a/core/modules/user/user.css
+++ b/core/modules/user/user.css
@@ -65,29 +65,6 @@ div.password-suggestions ul {
   width: 36.3em;
 }
 
-/* Generated by user.module but used by profile.module: */
-.profile {
-  clear: both;
-  margin: 1em 0;
-}
-.profile .user-picture {
-  float: right; /* LTR */
-  margin: 0 1em 1em 0; /* LTR */
-}
-.profile h2 {
-  border-bottom: 1px solid #ccc;
-}
-.profile dl {
-  margin: 0 0 1.5em 0;
-}
-.profile dt {
-  margin: 0 0 0.2em 0;
-  font-weight: bold;
-}
-.profile dd {
-  margin: 0 0 1em 0;
-}
-
 /**
  * Toolbar icon.
  */
diff --git a/core/modules/user/user.install b/core/modules/user/user.install
index 3bc837f65d716b4e9886aa3a0bd9e8db22a35364..28511d3561342f4d9b9dd45d1b98e20306aef727 100644
--- a/core/modules/user/user.install
+++ b/core/modules/user/user.install
@@ -5,6 +5,8 @@
  * Install, update and uninstall functions for the user module.
  */
 
+use Drupal\Component\Uuid\Uuid;
+
 /**
  * Implements hook_schema().
  */
@@ -120,12 +122,6 @@ function user_schema() {
         'default' => '',
         'description' => 'The {language}.langcode that the user prefers for viewing administration pages.',
       ),
-      'picture' => array(
-        'type' => 'int',
-        'not null' => TRUE,
-        'default' => 0,
-        'description' => "Foreign key: {file_managed}.fid of user's picture.",
-      ),
       'init' => array(
         'type' => 'varchar',
         'length' => 254,
@@ -145,7 +141,6 @@ function user_schema() {
       'access' => array('access'),
       'created' => array('created'),
       'mail' => array('mail'),
-      'picture' => array('picture'),
     ),
     'unique keys' => array(
       'uuid' => array('uuid'),
@@ -627,6 +622,247 @@ function user_update_8010() {
   ));
 }
 
+/**
+ * Create user picture field.
+ */
+function user_update_8011() {
+  global $user;
+
+  // User pictures can only be migrated to the new user picture image field
+  // if Image module is installed.
+  if (!module_exists('image')) {
+    module_enable(array('image'));
+  }
+
+  if ($default_image = update_variable_get('user_picture_default', '')) {
+    $picture_directory =  update_variable_get('file_default_scheme', 'public') . '://' . update_variable_get('user_picture_path', 'pictures');
+    file_prepare_directory($picture_directory, FILE_CREATE_DIRECTORY);
+    $destination = file_stream_wrapper_uri_normalize($picture_directory . '/' . drupal_basename($default_image));
+    // The file entity needs to be created manually as entities can not be
+    // created/saved during the upgrade path. Attempt to replicate the behavior
+    // of file_save_data() by updating an eventually existing record for that
+    // file.
+    file_unmanaged_save_data($default_image, $destination, FILE_EXISTS_REPLACE);
+    $uuid = new Uuid();
+    db_merge('file_managed')
+      ->key(array(
+        'uri' => $destination,
+      ))
+      ->fields(array(
+        'uid' => $user->uid,
+        'status' => FILE_STATUS_PERMANENT,
+        'filename' => drupal_basename($destination),
+        'uuid' => $uuid->generate(),
+        'langcode' => LANGUAGE_NOT_SPECIFIED,
+        'filesize' => filesize($destination),
+        'filemime' => file_get_mimetype($destination),
+        'timestamp' => REQUEST_TIME,
+      ))
+      ->execute();
+    $default_image_fid = db_query('SELECT fid FROM {file_managed} WHERE uri = :uri', array(':uri' => $destination))->fetchField();
+  }
+  $settings = array(
+    // In D7, user pictures did not require Image module to work. Image module
+    // only allowed usage of an image style to format user pictures in the
+    // output. The 'user_pictures' variable had a global effect on the
+    // presence of the user picture functionality before. The new user picture
+    // image field is created regardless of that global setting, which means
+    // the field appears on the user account form after migration, even if
+    // user pictures were disabled previously. The picture is only hidden in
+    // the output.
+    'formatter' => update_variable_get('user_pictures', 0) ? 'image' : 'hidden',
+    'file_directory' => update_variable_get('user_picture_path', 'pictures'),
+    'default_image' => !empty($default_image_fid) ? $default_image_fid : 0,
+    'image_style' => update_variable_get('user_picture_style', ''),
+    'max_resolution' => update_variable_get('user_picture_dimensions', '85x85'),
+    'max_filesize' => update_variable_get('user_picture_file_size', '30') . ' KB',
+    'description' => update_variable_get('user_picture_guidelines', ''),
+  );
+
+  $field = _user_install_picture_field($settings);
+
+  // Add file usage for the default field.
+  if (!empty($default_image_fid)) {
+    db_insert('file_usage')
+      ->fields(array(
+        'fid' => $default_image_fid,
+        'module' => 'image',
+        'type' => 'default_image',
+        'id' => $field['id'],
+        'count' => 1,
+      ))
+      ->execute();
+  }
+
+  // Update the user bundle settings and hide the member_for extra field.
+  $settings = update_variable_get('field_bundle_settings_user__user');
+  $settings['extra_fields']['display']['member_for']['compact'] = array(
+    'weight' => 0,
+    'visible' => FALSE,
+  );
+  update_variable_set('field_bundle_settings_user__user', $settings);
+
+  // Delete old variables.
+  update_variable_del('user_pictures');
+  update_variable_del('user_picture_path');
+  update_variable_del('user_picture_default');
+  update_variable_del('user_picture_style');
+  update_variable_del('user_picture_dimensions');
+  update_variable_del('user_picture_file_size');
+  update_variable_del('user_picture_guidelines');
+}
+
+/**
+ * Migrate {users}.picture to 'user_picture' image field.
+ */
+function user_update_8012(&$sandbox) {
+  // Initialize total values to process.
+  if (!isset($sandbox['total'])) {
+    $sandbox['total'] = (int) db_query('SELECT COUNT(picture) FROM {users} WHERE picture > 0')->fetchField();
+    $sandbox['processed'] = 0;
+  }
+
+  if ($sandbox['total']) {
+    // Retrieve next 20 rows to migrate.
+    $rows = db_query_range('SELECT uid, picture FROM {users} WHERE picture > 0', 0, 20)->fetchAllKeyed();
+    foreach ($rows as $uid => $fid) {
+      // Add a row to the field data and revision tables.
+      db_insert('field_data_user_picture')
+        ->fields(array(
+          'entity_type' => 'user',
+          'bundle' => 'user',
+          'entity_id' => $uid,
+          'revision_id' => $uid,
+          'langcode' => LANGUAGE_NOT_SPECIFIED,
+          'delta' => 0,
+          'user_picture_fid' => $fid,
+        ))
+        ->execute();
+      db_insert('field_revision_user_picture')
+        ->fields(array(
+          'entity_type' => 'user',
+          'bundle' => 'user',
+          'entity_id' => $uid,
+          'revision_id' => $uid,
+          'langcode' => LANGUAGE_NOT_SPECIFIED,
+          'delta' => 0,
+          'user_picture_fid' => $fid,
+        ))
+        ->execute();
+
+      // Update file usage from user to file module.
+      // @see file_field_insert()
+      // Old: file_usage_add($picture, 'user', 'user', $entity->uid);
+      // New: file_usage_add(file_load($item['fid']), 'file', $entity_type, $id);
+      db_update('file_usage')
+        ->condition('fid', $fid)
+        ->condition('module', 'user')
+        ->condition('type', 'user')
+        ->condition('id', $uid)
+        ->fields(array(
+          'module' => 'file',
+        ))
+        ->execute();
+    }
+
+    // Set picture column of the migrated users to 0.
+    db_update('users')
+      ->fields(array(
+        'picture' => 0,
+      ))
+      ->condition('uid', array_keys($rows))
+      ->execute();
+
+    // Report status.
+    $sandbox['processed'] += count($rows);
+  }
+  $sandbox['#finished'] = $sandbox['total'] ? $sandbox['processed'] / $sandbox['total'] : 1;
+
+}
+
+/**
+ * Deletes {users}.picture field.
+ */
+function user_update_8013() {
+  db_drop_field('users', 'picture');
+}
+
 /**
  * @} End of "addtogroup updates-7.x-to-8.x".
  */
+
+/**
+ * Creates a user picture image field for the User entity.
+ */
+function _user_install_picture_field(array $settings = array()) {
+  $t = get_t();
+  $settings += array(
+    'formatter' => 'image',
+    'file_directory' => 'pictures',
+    'default_image' => 0,
+    'image_style' => 'thumbnail',
+    'max_resolution' => '85x85',
+    'max_filesize' => '30 KB',
+    'description' => $t('Your virtual face or picture.'),
+  );
+
+  $field = array(
+    'field_name' => 'user_picture',
+    'module' => 'image',
+    'type' => 'image',
+    'cardinality' => 1,
+    'locked' => FALSE,
+    'indexes' => array('fid' => array('fid')),
+    'settings' => array(
+      'uri_scheme' => 'public',
+      'default_image' => FALSE,
+    ),
+    'storage' => array(
+      'type' => 'field_sql_storage',
+      'settings' => array(),
+    ),
+  );
+  _update_7000_field_create_field($field);
+
+  $instance = array(
+    'field_name' => 'user_picture',
+    'entity_type' => 'user',
+    'label' => 'Picture',
+    'bundle' => 'user',
+    'description' => $settings['description'],
+    'required' => FALSE,
+    'settings' => array(
+      'file_extensions' => 'png gif jpg jpeg',
+      'file_directory' => $settings['file_directory'],
+      'max_filesize' => $settings['max_filesize'],
+      'alt_field' => 0,
+      'title_field' => 0,
+      'max_resolution' => $settings['max_resolution'],
+      'min_resolution' => '',
+      'default_image' => $settings['default_image'],
+    ),
+    'widget' => array(
+      'module' => 'image',
+      'type' => 'image_image',
+      'settings' => array(
+        'progress_indicator' => 'throbber',
+        'preview_image_style' => 'thumbnail',
+      ),
+      'weight' => -1,
+    ),
+    'display' => array(
+      'default' => array(
+        'label' => 'hidden',
+        'type' => $settings['formatter'],
+        'settings' => array('image_style' => 'thumbnail', 'image_link' => 'content'),
+      ),
+      'compact' => array(
+        'label' => 'hidden',
+        'type' => $settings['formatter'],
+        'settings' => array('image_style' => $settings['image_style'], 'image_link' => 'content'),
+      ),
+    ),
+  );
+  _update_7000_field_create_instance($field, $instance);
+  return $field;
+}
diff --git a/core/modules/user/user.module b/core/modules/user/user.module
index 74031773d876d035f09022032b6b43041e7e902c..93c48e14ec6b8bf036c056161994e0a6010b8026 100644
--- a/core/modules/user/user.module
+++ b/core/modules/user/user.module
@@ -55,7 +55,7 @@ function user_help($path, $arg) {
       $output .= '<dt>' . t('User roles and permissions') . '</dt>';
       $output .= '<dd>' . t('<em>Roles</em> are used to group and classify users; each user can be assigned one or more roles. By default there are two roles: <em>anonymous user</em> (users that are not logged in) and <em>authenticated user</em> (users that are registered and logged in). Depending on choices you made when you installed Drupal, the installation process may have defined more roles, and you can create additional custom roles on the <a href="@roles">Roles page</a>. After creating roles, you can set permissions for each role on the <a href="@permissions_user">Permissions page</a>. Granting a permission allows users who have been assigned a particular role to perform an action on the site, such as viewing a particular type of content, editing or creating content, administering settings for a particular module, or using a particular function of the site (such as search).', array('@permissions_user' => url('admin/people/permissions'), '@roles' => url('admin/people/roles'))) . '</dd>';
       $output .= '<dt>' . t('Account settings') . '</dt>';
-      $output .= '<dd>' . t('The <a href="@accounts">Account settings page</a> allows you to manage settings for the displayed name of the anonymous user role, personal contact forms, user registration, and account cancellation. On this page you can also manage settings for account personalization (including signatures and user pictures), and adapt the text for the e-mail messages that are sent automatically during the user registration process.', array('@accounts'  => url('admin/config/people/accounts'))) . '</dd>';
+      $output .= '<dd>' . t('The <a href="@accounts">Account settings page</a> allows you to manage settings for the displayed name of the anonymous user role, personal contact forms, user registration, and account cancellation. On this page you can also manage settings for account personalization (including signatures), and adapt the text for the e-mail messages that are sent automatically during the user registration process.', array('@accounts'  => url('admin/config/people/accounts'))) . '</dd>';
       $output .= '</dl>';
       return $output;
     case 'admin/people/create':
@@ -85,10 +85,6 @@ function user_help($path, $arg) {
  */
 function user_theme() {
   return array(
-    'user_picture' => array(
-      'variables' => array('account' => NULL),
-      'template' => 'user-picture',
-    ),
     'user_profile' => array(
       'render element' => 'elements',
       'template' => 'user-profile',
@@ -144,6 +140,44 @@ function user_label($entity_type, $entity) {
   return user_format_name($entity);
 }
 
+/**
+ * Populates $entity->account for each prepared entity.
+ *
+ * Called by hook_entity_prepare_view() implementations.
+ *
+ * @param array $entities
+ *   The entities keyed by entity ID.
+ */
+function user_attach_accounts(array $entities) {
+  $uids = array();
+  foreach ($entities as $entity) {
+    $uids[] = $entity->uid;
+  }
+  $uids = array_unique($uids);
+  $accounts = user_load_multiple($uids);
+  $anonymous = drupal_anonymous_user();
+  foreach ($entities as $id => $entity) {
+    if (isset($accounts[$entity->uid])) {
+      $entities[$id]->account = $accounts[$entity->uid];
+    }
+    else {
+      $entities[$id]->account = $anonymous;
+    }
+  }
+}
+
+/**
+ * Returns whether this site supports the default user picture feature.
+ *
+ * This approach preserves compatibility with node/comment templates. Alternate
+ * user picture implementations (e.g., Gravatar) should provide their own
+ * add/edit/delete forms and populate the 'picture' variable during the
+ * preprocess stage.
+ */
+function user_picture_enabled() {
+  return (bool) field_info_instance('user', 'user_picture', 'user');
+}
+
 /**
  * Implements hook_field_info_alter().
  */
@@ -328,29 +362,6 @@ function user_validate_name($name) {
   }
 }
 
-/**
- * Validates an image uploaded by a user.
- *
- * @see AccountFormController::form()
- */
-function user_validate_picture(&$form, &$form_state) {
-  // If required, validate the uploaded picture.
-  $validators = array(
-    'file_validate_is_image' => array(),
-    'file_validate_image_resolution' => array(variable_get('user_picture_dimensions', '85x85')),
-    'file_validate_size' => array(variable_get('user_picture_file_size', '30') * 1024),
-  );
-
-  // Save the file as a temporary file.
-  $file = file_save_upload('picture_upload', $validators);
-  if ($file === FALSE) {
-    form_set_error('picture_upload', t("Failed to upload the picture image; the %directory directory doesn't exist or is not writable.", array('%directory' => variable_get('user_picture_path', 'pictures'))));
-  }
-  elseif ($file !== NULL) {
-    $form_state['values']['picture_upload'] = $file;
-  }
-}
-
 /**
  * Generate a random alphanumeric password.
  */
@@ -520,45 +531,6 @@ function user_permission() {
   );
 }
 
-/**
- * Implements hook_file_download().
- *
- * Ensure that user pictures (avatars) are always downloadable.
- */
-function user_file_download($uri) {
-  if (strpos(file_uri_target($uri), variable_get('user_picture_path', 'pictures') . '/picture-') === 0) {
-    $info = image_get_info($uri);
-    return array('Content-Type' => $info['mime_type']);
-  }
-}
-
-/**
- * Implements hook_file_move().
- */
-function user_file_move(File $file, File $source) {
-  // If a user's picture is replaced with a new one, update the record in
-  // the users table.
-  if (isset($file->fid) && isset($source->fid) && $file->fid != $source->fid) {
-    db_update('users')
-      ->fields(array(
-        'picture' => $file->fid,
-      ))
-      ->condition('picture', $source->fid)
-      ->execute();
-  }
-}
-
-/**
- * Implements hook_file_predelete().
- */
-function user_file_predelete(File $file) {
-  // Remove any references to the file.
-  db_update('users')
-    ->fields(array('picture' => 0))
-    ->condition('picture', $file->fid)
-    ->execute();
-}
-
 /**
  * Implements hook_search_info().
  */
@@ -620,10 +592,6 @@ function user_search_execute($keys = NULL, $conditions = NULL) {
  * Implements hook_user_view().
  */
 function user_user_view($account) {
-  $account->content['user_picture'] = array(
-    '#markup' => theme('user_picture', array('account' => $account)),
-    '#weight' => -10,
-  );
   $account->content['member_for'] = array(
     '#type' => 'item',
     '#title' => t('Member for'),
@@ -901,55 +869,6 @@ function user_template_preprocess_default_variables_alter(&$variables) {
   $variables['logged_in'] = ($user->uid > 0);
 }
 
-/**
- * Process variables for user-picture.tpl.php.
- *
- * The $variables array contains the following arguments:
- * - $account: A user, node or comment object with 'name', 'uid' and 'picture'
- *   fields.
- *
- * @see user-picture.tpl.php
- */
-function template_preprocess_user_picture(&$variables) {
-  $variables['user_picture'] = '';
-  if (variable_get('user_pictures', 0)) {
-    $account = $variables['account'];
-    if (!empty($account->picture)) {
-      // @TODO: Ideally this function would only be passed file entities, but
-      // since there's a lot of legacy code that JOINs the {users} table to
-      // {node} or {comments} and passes the results into this function if we
-      // a numeric value in the picture field we'll assume it's a file id
-      // and load it for them. Once we've got user_load_multiple() and
-      // comment_load_multiple() functions the user module will be able to load
-      // the picture files in mass during the object's load process.
-      if (is_numeric($account->picture)) {
-        $account->picture = file_load($account->picture);
-      }
-      if (!empty($account->picture->uri)) {
-        $filepath = $account->picture->uri;
-      }
-    }
-    elseif (variable_get('user_picture_default', '')) {
-      $filepath = variable_get('user_picture_default', '');
-    }
-    if (isset($filepath)) {
-      $alt = t("@user's picture", array('@user' => user_format_name($account)));
-      // If the image does not have a valid Drupal scheme (for eg. HTTP),
-      // don't load image styles.
-      if (module_exists('image') && file_valid_uri($filepath) && $style = variable_get('user_picture_style', '')) {
-        $variables['user_picture'] = theme('image_style', array('style_name' => $style, 'uri' => $filepath, 'alt' => $alt, 'title' => $alt));
-      }
-      else {
-        $variables['user_picture'] = theme('image', array('uri' => $filepath, 'alt' => $alt, 'title' => $alt));
-      }
-      if (!empty($account->uid) && user_access('access user profiles')) {
-        $attributes = array('attributes' => array('title' => t('View user profile.')), 'html' => TRUE);
-        $variables['user_picture'] = l($variables['user_picture'], "user/$account->uid", $attributes);
-      }
-    }
-  }
-}
-
 /**
  * Preprocesses variables for theme_username().
  *
@@ -1263,7 +1182,7 @@ function user_menu() {
   );
   $items['admin/config/people/accounts'] = array(
     'title' => 'Account settings',
-    'description' => 'Configure default behavior of users, including registration requirements, e-mails, fields, and user pictures.',
+    'description' => 'Configure default behavior of users, including registration requirements, e-mails, and fields.',
     'page callback' => 'drupal_get_form',
     'page arguments' => array('user_admin_settings'),
     'access arguments' => array('administer users'),
@@ -2023,8 +1942,6 @@ function user_view_page($account) {
  *
  * When viewing a user profile, the $page array contains:
  *
- * - $page['content']['user_picture']:
- *   User's rendered picture.
  * - $page['content']['member_for']:
  *   Contains the default "Member for" profile data for a user.
  * - $page['content']['#account']:
@@ -2875,6 +2792,10 @@ function user_form_process_password_confirm($element) {
 
 /**
  * Implements hook_node_load().
+ *
+ * @todo Deprecated by $node->author, attached in
+ *   \Drupal\node\NodeRenderController::buildContent(). Update code that
+ *   depends on these properties.
  */
 function user_node_load($nodes, $types) {
   // Build an array of all uids for node authors, keyed by nid.
@@ -2883,36 +2804,16 @@ function user_node_load($nodes, $types) {
     $uids[$nid] = $node->uid;
   }
 
-  // Fetch name, picture, and data for these users.
-  $user_fields = db_query("SELECT uid, name, picture, data FROM {users} WHERE uid IN (:uids)", array(':uids' => $uids))->fetchAllAssoc('uid');
+  // Fetch name and data for these users.
+  $user_fields = db_query("SELECT uid, name, data FROM {users} WHERE uid IN (:uids)", array(':uids' => $uids))->fetchAllAssoc('uid');
 
   // Add these values back into the node objects.
   foreach ($uids as $nid => $uid) {
     $nodes[$nid]->name = $user_fields[$uid]->name;
-    $nodes[$nid]->picture = $user_fields[$uid]->picture;
     $nodes[$nid]->data = $user_fields[$uid]->data;
   }
 }
 
-/**
- * Implements hook_image_style_delete().
- */
-function user_image_style_delete($style) {
-  // If a style is deleted, update the variables.
-  // Administrators choose a replacement style when deleting.
-  user_image_style_save($style);
-}
-
-/**
- * Implements hook_image_style_save().
- */
-function user_image_style_save($style) {
-  // If a style is renamed, update the variables that use it.
-  if ($style->id() != $style->getOriginalID()) {
-    variable_set('user_picture_style', $style->id());
-  }
-}
-
 /**
  * Implements hook_action_info().
  */
diff --git a/core/modules/user/user.views.inc b/core/modules/user/user.views.inc
index 295278a2ecbcb9b6cfcd82c6631f5b80acd6f8fd..170759a91c85fc0abb7ec9d2a3a9d9e6c49b1ae1 100644
--- a/core/modules/user/user.views.inc
+++ b/core/modules/user/user.views.inc
@@ -153,25 +153,6 @@ function user_views_data() {
     ),
   );
 
-  // picture
-  $data['users']['picture'] = array(
-    'title' => t('Picture'),
-    'help' => t("The user's picture, if allowed."), // The help that appears on the UI,
-    // Information for displaying the uid
-    'field' => array(
-      'id' => 'user_picture',
-      'click sortable' => TRUE,
-    ),
-    'sort' => array(
-      'id' => 'standard',
-    ),
-    'filter' => array(
-      'id' => 'boolean',
-      'label' => t('Has Avatar'),
-      'type' => 'yes-no',
-    ),
-  );
-
   // link
   $data['users']['view_user'] = array(
     'field' => array(
diff --git a/core/profiles/standard/standard.install b/core/profiles/standard/standard.install
index c063a6dc0b3449871bc2b7931dfe4e10acffc6d0..071bf31ee636f93def975b496d84651aa8114226 100644
--- a/core/profiles/standard/standard.install
+++ b/core/profiles/standard/standard.install
@@ -253,12 +253,6 @@ function standard_install() {
   // Don't display date and author information for "Basic page" nodes by default.
   variable_set('node_submitted_page', FALSE);
 
-  // Enable user picture support and set the default to a square thumbnail option.
-  variable_set('user_pictures', '1');
-  variable_set('user_picture_dimensions', '1024x1024');
-  variable_set('user_picture_file_size', '800');
-  variable_set('user_picture_style', 'thumbnail');
-
   // Allow visitor account creation with administrative approval.
   $user_settings = config('user.settings');
   $user_settings->set('register', USER_REGISTER_VISITORS_ADMINISTRATIVE_APPROVAL)->save();
@@ -383,6 +377,17 @@ function standard_install() {
   );
   field_create_instance($instance);
 
+  // Create user picture field.
+  module_load_install('user');
+  _user_install_picture_field();
+  // Remove 'summary' pseudo-field from compact view mode on the User entity.
+  $bundle_settings = field_bundle_settings('user', 'user');
+  $bundle_settings['extra_fields']['display']['member_for']['compact'] = array(
+    'visible' => FALSE,
+    'weight' => 10,
+  );
+  field_bundle_settings('user', 'user', $bundle_settings);
+
   // Enable default permissions for system roles.
   $filtered_html_permission = filter_permission_name($filtered_html_format);
   user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, array('access content', 'access comments', $filtered_html_permission));
diff --git a/core/themes/bartik/css/style-rtl.css b/core/themes/bartik/css/style-rtl.css
index 711a742da8ca0f0ebfd7c0ec43f896ec4fe468f1..74f2950c1b8c47dcfa569b62246ca736d27c3fd4 100644
--- a/core/themes/bartik/css/style-rtl.css
+++ b/core/themes/bartik/css/style-rtl.css
@@ -83,9 +83,9 @@ ul.tips {
 
 /* ----------------- Content ------------------ */
 
-.submitted .user-picture img {
+.submitted .field-name-field-user-picture img {
   float: right;
-  margin-left: 5px;
+  margin-left: 20px;
   margin-right: 0;
 }
 .field-type-taxonomy-term-reference .field-label {
@@ -104,7 +104,7 @@ ul.tips {
 
 /* ----------------- Comments ----------------- */
 
-.comment .user-picture img {
+.comment .field-name-field-user-picture img {
   margin-right: 0;
 }
 .comment .attribution {
diff --git a/core/themes/bartik/css/style.css b/core/themes/bartik/css/style.css
index 38e1afa875b938a9776f489e2ae7c0458794af33..ffe0629027e5e2977671aba08a57dd0af6e2a2fd 100644
--- a/core/themes/bartik/css/style.css
+++ b/core/themes/bartik/css/style.css
@@ -622,10 +622,9 @@ h1#page-title {
   color: #68696b;
   margin-bottom: -5px;
 }
-.submitted .user-picture img {
+.submitted .field-name-field-user-picture img {
   float: left; /* LTR */
-  height: 20px;
-  margin: 1px 5px 0 0; /* LTR */
+  margin: 1px 20px 0 0; /* LTR */
 }
 .field-type-taxonomy-term-reference {
   margin: 0 0 1.2em;
@@ -657,7 +656,7 @@ h1#page-title {
   text-align: right;
 }
 .field-type-image img,
-.user-picture img {
+.field-name-field-user-picture img {
   margin: 0 0 1em;
 }
 ul.links {
@@ -678,7 +677,7 @@ ul.links {
 .comment h2.title {
   margin-bottom: 1em;
 }
-.comment div.user-picture img {
+.comment .field-name-field-user-picture img {
   margin-left: 0; /* LTR */
 }
 .comment {
@@ -1058,7 +1057,7 @@ div.messages {
 
 /* -------------- User Profile   -------------- */
 
-.profile .user-picture {
+.profile .field-name-field-user-picture {
   float: none;
 }
 
diff --git a/core/themes/bartik/templates/comment.tpl.php b/core/themes/bartik/templates/comment.tpl.php
index ef525c1230b9b496e8783b4c5e3494dd830033c1..2b285d2149fe4a1058345f9e87e5b78712c78735 100644
--- a/core/themes/bartik/templates/comment.tpl.php
+++ b/core/themes/bartik/templates/comment.tpl.php
@@ -20,7 +20,6 @@
  * - $permalink: Comment permalink.
  * - $submitted: Submission information created from $author and $created
  *   during template_preprocess_comment().
- * - $picture: Authors picture.
  * - $signature: Authors signature.
  * - $status: Comment status. Possible values are:
  *   unpublished, published, or preview.
@@ -73,7 +72,7 @@
 
   <div class="attribution">
 
-    <?php print $user_picture; ?>
+    <?php print render($user_picture); ?>
 
     <div class="submitted">
       <p class="commenter-name">
diff --git a/core/update.php b/core/update.php
index 98296bbaf81f81957db0676314e0195e22615cbd..4e74c0c6cba8fcddddd883683f06c046a0da38d2 100644
--- a/core/update.php
+++ b/core/update.php
@@ -200,7 +200,8 @@ function update_results_page() {
     $output = '<p>Updates were attempted. If you see no failures below, you may proceed happily back to your <a href="' . base_path() . '">site</a>. Otherwise, you may need to update your database manually.' . $log_message . '</p>';
   }
   else {
-    list($module, $version) = array_pop(reset($_SESSION['updates_remaining']));
+    $last = reset($_SESSION['updates_remaining']);
+    list($module, $version) = array_pop($last);
     $output = '<p class="error">The update process was aborted prematurely while running <strong>update #' . $version . ' in ' . $module . '.module</strong>.' . $log_message;
     if (module_exists('dblog')) {
       $output .= ' You may need to check the <code>watchdog</code> database table manually.';
diff --git a/core/modules/comment/templates/comment.tpl.php b/core/modules/comment/templates/comment.tpl.php
index 890e4572b608892dea249b992fae0cf5202a2a58..5a8a37e50284c1b64345b2d736edbaa35ec2dc3a 100644
--- a/core/modules/comment/templates/comment.tpl.php
+++ b/core/modules/comment/templates/comment.tpl.php
@@ -20,7 +20,8 @@
  * - $permalink: Comment permalink.
  * - $submitted: Submission information created from $author and $created during
  *   template_preprocess_comment().
  * - $user_picture: The comment author's picture from user-picture.tpl.php.
  * - $signature: Authors signature.
  * - $status: Comment status. Possible values are:
  *   unpublished, published, or preview.
@@ -79,7 +80,7 @@
   <?php print render($title_suffix); ?>
 
   <footer>
-    <?php print $user_picture; ?>
+    <?php print render($user_picture); ?>
     <p class="submitted"><?php print $submitted; ?></p>
     <?php
       // Indicate the semantic relationship between parent and child comments
@@ -20,7 +20,8 @@
  * - $submitted: Submission information created from $author and $created during
  *   template_preprocess_comment().
- * - $user_picture: The comment author's picture from user-picture.tpl.php.
+ * - $user_picture: The comment author's picture. Use render($user_picture) to
+ *   print it.
  * - $signature: Authors signature.
  * - $status: Comment status. Possible values are:
diff --git a/core/modules/node/templates/node.tpl.php b/core/modules/node/templates/node.tpl.php
index ca9a75b0044bbb91a5c91de12f2b2a0a3afec3cc..196d26fbcafc25f2f030cd5aae6d89b102962f9e 100644
--- a/core/modules/node/templates/node.tpl.php
+++ b/core/modules/node/templates/node.tpl.php
@@ -10,7 +10,7 @@
  *   or print a subset such as render($content['field_example']). Use
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
  * - $user_picture: The node author's picture from user-picture.tpl.php.
  * - $date: Formatted creation date. Preprocess functions can reformat it by
  *   calling format_date() with the desired parameters on the $created variable.
  * - $name: Themed username of node author output from theme_username().
@@ -86,7 +86,7 @@
 
   <?php if ($display_submitted): ?>
     <footer>
-      <?php print $user_picture; ?>
+      <?php print render($user_picture); ?>
       <p class="submitted"><?php print $submitted; ?></p>
     </footer>
   <?php endif; ?>
@@ -10,7 +10,7 @@
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
- * - $user_picture: The node author's picture from user-picture.tpl.php.
+ * - $user_picture: The node author's picture. Use render() to print it.
  * - $date: Formatted creation date. Preprocess functions can reformat it by
  *   calling format_date() with the desired parameters on the $created variable.
diff --git a/core/themes/bartik/templates/node.tpl.php b/core/themes/bartik/templates/node.tpl.php
index 8467a4dc0f24094313c8bda43be43f606d0401aa..0038e923b244784f65f6ed381a7dd88d28a2794b 100644
--- a/core/themes/bartik/templates/node.tpl.php
+++ b/core/themes/bartik/templates/node.tpl.php
@@ -10,7 +10,7 @@
  *   or print a subset such as render($content['field_example']). Use
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
  * - $user_picture: The node author's picture from user-picture.tpl.php.
  * - $date: Formatted creation date. Preprocess functions can reformat it by
  *   calling format_date() with the desired parameters on the $created variable.
  * - $name: Themed username of node author output from theme_username().
@@ -88,7 +88,7 @@
 
   <?php if ($display_submitted): ?>
     <div class="meta submitted">
-      <?php print $user_picture; ?>
+      <?php print render($user_picture); ?>
       <?php print $submitted; ?>
     </div>
   <?php endif; ?>
@@ -10,7 +10,7 @@
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
- * - $user_picture: The node author's picture from user-picture.tpl.php.
+ * - $user_picture: The node author's picture. Use render() when printing.
  * - $date: Formatted creation date. Preprocess functions can reformat it by
  *   calling format_date() with the desired parameters on the $created variable.